# fluxx - modern Finite State Machines & more
The results of my experiments with FSM's and trait-based programming based on Python 3 enums and sets.

Check the Showcase notebook in docs on https://github.com/amogorkon/fluxx for working examples and documentation.

Have fun!
- Anselm Kiefner
